<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Uygulama Vekil Sunucusu</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Vekil Sunucu Türü</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Adresi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>İsteğe bağlı</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Yapılandırıldıktan sonra Başlatıcı&apos;daki uygulama bağlamı menüsünde &quot;Vekil Sunucu Kullan&quot; seçeneğini işaretleyin.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Geçersiz IP adresi</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Geçersiz port</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Bağlantıyı kes</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Bağlantıyı kes</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Bu yapılandırmayı silmek istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Kablolu Bağlantı %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Bağlantı Noktası</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Kablosuz Bağlantı %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE Bağlantısı %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Yeni VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN Türü</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Dışarı aktar</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Ağ</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Uygulama Vekil Sunucusu</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Kişisel Bağlantı Noktası</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Ağ Ayrıntıları</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Sistem Vekil Sunucusu</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Kablolu Ağ</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Kablosuz Ağ</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Uçak Kipi</translation>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Kablolu Ağ Adaptörü</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Ağ Bağlantısı Ekle</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Kablosuz Ağ Adaptörü</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Gizli ağa bağlan</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE Bağlantısı Oluştur</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN Durumu</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN Oluştur</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN&apos;yi İçe Aktar</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Vekil Sunucu Türü</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Yapılandırma Adresi</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Adresi</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Bağlantı Noktası</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Erişim Noktası Oluştur</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>Arayüz</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>Bant</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Ağ Geçidi</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Birincil DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Ağ Maskesi</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Ön Ek</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hız</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Uçak Kipi</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Geçersiz DNS adresi</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Bağlı Değil</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Aygıtın MAC Adresi</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Kopyalanmış MAC Adresi</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU Değerini Özelleştir</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>İsim zaten var</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Otomatik Bağlan</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Bağlantı Noktası</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Ayar Ekle</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Erişim Noktası Oluştur</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP Adresi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gereklidir</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Ağ Geçidi</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Tekrarlanan IP adresi</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Geçersiz IP adresi</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Geçersiz ağ maskesi</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Yalnızca bir ağ geçidine izin verilir</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Geçersiz ağ geçidi</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Ağ Maskesi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gereklidir</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Tekrarlanan IP adresi</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Geçersiz IP adresi</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Yalnızca bir ağ geçidine izin verilir</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Geçersiz ağ geçidi</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Ön Ek</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Elle</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Yoksay</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Adresi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Ağ Geçidi</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Sadece ilgili kaynaklarda uygulanır</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Yöntem</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Ağ Maskesi</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Ön Ek</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Geçersiz IP adresi</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Geçersiz ağ maskesi</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Geçersiz ağ geçidi</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Ağ</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP çakışması</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Yöntem</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Elle</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Yoksay</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Ağ Ayrıntıları</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Sistem Vekil Sunucusu</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Uygulama Vekil Sunucusu</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Uçak Kipi</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Ağ Ayrıntıları</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Ağ</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP çakışması</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Devre Dışı</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Elle</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Ağ Yöneticisi Yapılandır</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Kişisel Bağlantı Noktası</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Servis</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSD Veri Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Veri Küçültme Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCP Üst Bilgi Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>İletişim Kuralı Alanı Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Adres/Denetim Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP Echo Paketleri Gönder</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE Kullan</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Durumsal MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE Bağlantısı Oluştur</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Sistem Vekil Sunucusu</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Vekil Sunucu Türü</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>Elle</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>İsteğe bağlı</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP Vekil Sunucusu</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS Vekil Sunucusu</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP Vekil Sunucusu</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS Vekil Sunucusu</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Yukarıdaki bilgisayar ve etki alanları için vekil sunucu yapılandırmaları yoksay</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Yapılandırma Adresi</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Güvenlik</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tünellenmiş TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Korumalı EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Bu kullanıcı için parolayı kaydet</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Tüm kullanıcılar için parolayı kaydet</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Her zaman sor</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Devre Dışı</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonim</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Kimlik Doğrulandı</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>İkisi de</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Sürüm 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Sürüm 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP Kimlik Doğrulaması</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Kimlik</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Parola Ayarları</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Özel Anahtar</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Sertifikası</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Kullanıcı Sertifikası</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anonim Kimlik</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Sağlama</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC dosyası</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>İç Kimlik Doğrulaması</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP Sürümü</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Özel Parola</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Geçersiz parola</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Kişisel</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Kişisel</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Güvenlik</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Anahtar</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Zorunlu Güvenlik</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Geçersiz parola</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Kişisel</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Kurumsal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Kişisel</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Paylaşılan anahtar</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Açık sistem</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Güvenlik</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Doğrulama</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Anahtar</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Gelişmiş</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Ağ Geçidi Port Özelleştir</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Ağ Geçidi Port</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Yeniden Görüşme Sıklığını Özelleştir</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Yeniden Görüşme Sıklığı</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>LZO Veri Sıkıştırması Kullan</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>TCP Bağlantısı Kullan</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>TAP Aygıtı Kullan</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Tünel MTU Değerini Özelleştir</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>UDP Parça Boyutunu Özelleştir</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP Parça Boyutu</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Tünel TCP MSS&apos;yi Kısıtla</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Uzak Ana Bilgisayarları Rastgele Ayarla</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Gelişmiş</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (varsayılan)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Güvenli (varsayılan)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Zayıf</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>Kullanılabildiğinde NAT-T (varsayılan)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>Her Zaman NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Devre Dışı</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>1. DH Grubu</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>2. DH Grubu (varsayılan)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>5. DH Grubu</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Sunucu (varsayılan)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>2. DH Grubu</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Etki Alanı</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Yayınlayan</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Şifreleme</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT Geçiş Kipi</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH Grubu</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>İletme Gizliliği</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Yerel Port</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Ölü Eş Algılamayı Devre Dışı Bırak</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>IPsec Kullanılsın</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Grup Adı</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Grup Kimliği</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Ön Paylaşımlı Anahtar</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>1. Aşama Algoritmaları</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>2. Aşama Algoritmaları</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Geçersiz ağ geçidi</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Ağ Geçidi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Sertifikası</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Vekil Sunucu</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Cisco Güvenli Masaüstü Trojanına İzin Ver</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD Betiği</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Kullanıcı Sertifikası</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Özel Anahtar</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Anahtar Parolası için FSID kullan</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Geçersiz ağ geçidi</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Sertifikalar (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Parolalı Sertifikalar (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Statik Anahtar</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Kaydedildi</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Sor</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Zorunlu Değil</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Ağ Geçidi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Kimlik Doğrulama Türü</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Sertifikası</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Kullanıcı Sertifikası</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Özel Anahtar</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Parola Ayarları</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Özel Parola</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Anahtar Yönünü Özelleştir</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Anahtar Yönü</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Uzak IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Yerel IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Tüm Kullanılabilenler (varsayılan)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40 bit (daha az güvenli)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128 bit (en güvenli)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSD Veri Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Veri Küçültme Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCP Üst Bilgi Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>İletişim Kuralı Alanı Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Adres/Denetim Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP Echo Paketleri Gönder</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE Kullan</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Güvenlik</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Durumsal MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN Durumu</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN Oluştur</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN&apos;yi İçe Aktar</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>İçe Aktarma Hatası</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Dosya hatası</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Vekil Sunucu</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Zorunlu Değil</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Vekil Sunucu Türü</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Sunucu IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Başarısız Olduğunda Sürekli Dene</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA Dosyası</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Sertifika Uyarılarını Yoksay</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>TLS Sunucu Adı Eklentileri Kullan</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN Güvenliği</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Şifre</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Kimlik Doğrulama</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Geçersiz ağ geçidi</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Kaydedildi</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Sor</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Zorunlu Değil</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Ağ Geçidi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Parola Ayarları</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT Etki Alanı</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Vekil Sunucu</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Sunucu IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Geçersiz ağ geçidi</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Özel Anahtar</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH İstemci</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Akıllı Kart</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Ön Paylaşımlı Anahtar</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Ağ Geçidi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Sertifikası</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Kimlik Doğrulama Türü</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Kullanıcı Sertifikası</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>İç IP Adresi İste</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>UDP Enkapsülasyonu Kullan</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>IP Sıkıştırmasını Kullan</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Özel Şifreleme Tekliflerini Etkinleştir</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS Kimlik Doğrulaması</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>İstemci</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Sunucu</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Konu Eşleşmesi</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Uzak Sertifika Türü</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Anahtar Dosyası</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Anahtar Yönünü Özelleştir</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Anahtar Yönü</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Geçersiz ağ geçidi</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Kaydedildi</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Sor</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Zorunlu Değil</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Ağ Geçidi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Parola Ayarları</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Grup Adı</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Grup Parolası</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Karma Kimlik Doğrulaması Kullan</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA Dosyası</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Önce ağ kablosunu takın</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Kablolu Ağ Adaptörü</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Ağ Bağlantısı Ekle</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Ayarları Seç</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Kablosuz Ağ Adaptörü</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Erişim Noktasını Kapat</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Kablosuz bir ağa bağlanmak için erişim noktasını devre dışı bırakın</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Gizli ağa bağlan</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Bağlı Değil</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Aygıtın MAC Adresi</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU Değerini Özelleştir</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Bağlantı Noktası</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Güvenlik Türü</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bant</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Arayüz</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Ağ Maskesi</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Ağ Geçidi</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Birincil DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Ön Ek</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hız</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Aygıt devre dışı</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Bağandı ancak İnternet erişimi yok</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Bağlı değil</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Ağ kablosu takılı değil</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Bağlanıyor</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Kimlik doğrulanıyor</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>IP adresi elde ediliyor</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Bağlandı</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Bağlantı kesildi</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP çakışması</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Başarısız</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Adres elde ediliyor</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Kablolu Ağ</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Kablolu Ağ %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Kablosuz Ağ</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Kablosuz Ağ%1</translation>
    </message>
</context>
</TS>